##
##  r.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         r
Summary:      The R Statistical Computing System
URL:          http://www.r-project.org/
Vendor:       The R Foundation
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Algorithm
License:      GPL
Version:      4.5.0
Release:      20250417

#   list of sources
Source0:      http://cran.r-project.org/src/base/R-4/R-%{version}.tar.gz
Patch0:       r.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes, gcc::with_fortran = yes, make
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  readline, png, jpeg, zlib, bzip2, pcre
PreReq:       readline, png, jpeg, zlib, bzip2, pcre

%description
     R is a language and environment for statistical computing and
     graphics. It is similar to the S language and environment which
     was developed at Bell Laboratories (formerly AT&T, now Lucent
     Technologies) by John Chambers and colleagues. R can be considered
     as a different implementation of S. There are some important
     differences, but much code written for S runs unaltered under R.

     R provides a wide variety of statistical (linear and nonlinear
     modelling, classical statistical tests, time-series analysis,
     classification, clustering, ...) and graphical techniques, and is
     highly extensible. The S language is often the vehicle of choice
     for research in statistical methodology, and R provides an Open
     Source route to participation in that activity.

%track
    prog r = {
        version   = %{version}
        url       = http://cran.r-project.org/src/base/R-4/
        regex     = R-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n R-%{version}
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags openssl3 .}" \
    LIBS="-lssl -lcrypto" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --with-recommended-packages \
        --with-readline \
        --without-gnome \
        --disable-nls \
        --with-libpng \
        --with-jpeglib \
        --with-zlib \
        --with-bzlib \
        --with-pcre \
        --without-x
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install \
        prefix=$RPM_BUILD_ROOT%{l_prefix} \
        exec_prefix=$RPM_BUILD_ROOT%{l_prefix} \
        mandir=$RPM_BUILD_ROOT%{l_prefix}/man
    %{l_shtool} subst \
        -e 's;^\(R_HOME_DIR\)=.*;\1=%{l_prefix}/lib/r;' \
        -e 's;^\(R_SHARE_DIR\)=.*;\1=%{l_prefix}/lib/r/share;' \
        -e 's;^\(R_INCLUDE_DIR\)=.*;\1=%{l_prefix}/lib/r/include;' \
        -e 's;^\(R_DOC_DIR\)=.*;\1=%{l_prefix}/lib/r/doc;' \
        $RPM_BUILD_ROOT%{l_prefix}/bin/R \
        $RPM_BUILD_ROOT%{l_prefix}/lib/R/bin/R
    mv  $RPM_BUILD_ROOT%{l_prefix}/lib/R \
        $RPM_BUILD_ROOT%{l_prefix}/lib/r
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

